@@ -90,7 +90,6 @@ Kwave::NoiseDialog::NoiseDialog(QWidget *parent,
 
     // set default: 10%
     setMode(m_mode);
-    updateDisplay(+0.1);
 
     connect(buttonBox_Help->button(QDialogButtonBox::Help), SIGNAL(clicked()),
             this,   SLOT(invokeHelp()));
@@ -106,7 +105,7 @@ Kwave::NoiseDialog::~NoiseDialog()
     listenToggled(false);
 
     delete m_overview_cache;
-    m_overview_cache = Q_NULLPTR;
+    m_overview_cache = nullptr;
 }
 
 //***************************************************************************
@@ -140,6 +139,7 @@ void Kwave::NoiseDialog::setMode(Mode mode)
             spinbox->setMaximum(0);
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
 
     // update the value in the display
@@ -278,6 +278,7 @@ void Kwave::NoiseDialog::updateDisplay(double value)
             spinbox->setInverse(false);
             break;
         }
+        DEFAULT_IMPOSSIBLE;
     }
 
     // update the spinbox
@@ -316,6 +317,7 @@ void Kwave::NoiseDialog::spinboxChanged(int pos)
             // decibel
             factor = pow(10.0, pos / 20.0);
             break;
+        DEFAULT_IMPOSSIBLE;
     }
 
     updateDisplay(factor);
@@ -348,6 +350,7 @@ void Kwave::NoiseDialog::setParams(QStringList &params)
     setMode(m_mode);
 
     // update factor
+    m_noise = -1.0 * factor; // just to get an initial refresh (fake change)
     updateDisplay(factor);
 }
 
@@ -382,3 +385,5 @@ void Kwave::NoiseDialog::invokeHelp()
 
 //***************************************************************************
 //***************************************************************************
+
+#include "moc_NoiseDialog.cpp"
